'use strict'

var indexArray = require('./')
var tape = require('tape')

var sample = [
  {id: 'e6a7g89', name: 'Joe Bloggs', email: 'joe@bloggs.com'},
  {id: '300e9ea', name: 'John Doe', email: 'john@doe.com'},

  // some duplicate key values
  {id: 'f82a894', name: 'John Doe', email: 'john@doe.com'}
]

tape('keys - {}', function (test) {
  test.plan(6)
  test.equal(indexArray(sample, 'id')['e6a7g89'], sample[0])
  test.equal(indexArray(sample, 'id')['300e9ea'], sample[1])
  test.equal(indexArray(sample, 'name')['Joe Bloggs'], sample[0])
  test.equal(indexArray(sample, 'name')['John Doe'], sample[1])
  test.equal(indexArray(sample, 'email')['joe@bloggs.com'], sample[0])
  test.equal(indexArray(sample, 'email')['john@doe.com'], sample[1])
})

tape('keys - {arraify: true}', function (test) {
  test.plan(8)
  var op = {arraify: true}
  test.deepEqual(indexArray(sample, 'id', op)['e6a7g89'], [sample[0]])
  test.deepEqual(indexArray(sample, 'id', op)['300e9ea'], [sample[1]])
  test.deepEqual(indexArray(sample, 'name', op)['Joe Bloggs'], [sample[0]])
  test.deepEqual(indexArray(sample, 'name', op)['John Doe'][0].id, '300e9ea')
  test.deepEqual(indexArray(sample, 'name', op)['John Doe'][1].id, 'f82a894')
  test.deepEqual(indexArray(sample, 'email', op)['joe@bloggs.com'], [sample[0]])
  test.deepEqual(indexArray(sample, 'email', op)['john@doe.com'][0].id, '300e9ea')
  test.deepEqual(indexArray(sample, 'email', op)['john@doe.com'][1].id, 'f82a894')
})

tape('keys - {overwrite: true}', function (test) {
  test.plan(6)
  var op = {overwrite: true}
  test.equal(indexArray(sample, 'id', op)['e6a7g89'], sample[0])
  test.equal(indexArray(sample, 'id', op)['300e9ea'], sample[1])
  test.equal(indexArray(sample, 'name', op)['Joe Bloggs'], sample[0])
  test.equal(indexArray(sample, 'name', op)['John Doe'], sample[2])
  test.equal(indexArray(sample, 'email', op)['joe@bloggs.com'], sample[0])
  test.equal(indexArray(sample, 'email', op)['john@doe.com'], sample[2])
})

tape('invalid input', function (test) {
  test.plan(2)

  sample = [1, 2, 3]
  test.equal(JSON.stringify(indexArray(sample, 'someKey')), '{}')

  sample = [{a: 1}, {a: 2}, {a: 3}]
  test.equal(JSON.stringify(indexArray(sample, 'someKey')), '{}')
})
